import { ContextConnector, ICompletionManager, KernelConnector } from '@jupyterlab/completer';
import { ISettingRegistry } from '@jupyterlab/settingregistry';
import { INotebookTracker } from '@jupyterlab/notebook';
import { CompletionConnector } from '../connectors/connector';
import { CustomConnector } from '../connectors/customConnector';
/**
 * The command IDs used by the console plugin.
 */
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.invoke = 'completer:invoke';
    CommandIDs.invokeNotebook = 'completer:invoke-notebook-1';
    CommandIDs.select = 'completer:select';
    CommandIDs.selectNotebook = 'completer:select-notebook-custom';
})(CommandIDs || (CommandIDs = {}));
const SETTINGS_PLUGIN_ID = 'jupyterlab_mutableai:settings-mutableai';
/**
 * Initialization data for the extension.
 */
const completer = {
    id: 'completer',
    autoStart: true,
    requires: [ICompletionManager, INotebookTracker, ISettingRegistry],
    activate: async (app, completionManager, notebooks, settings) => {
        console.log('Mutable AI custom completer extension is activated!');
        Promise.all([app.restored, settings.load(SETTINGS_PLUGIN_ID)]).then(([, setting]) => {
            // Modelled after completer-extension's notebooks plugin
            const enabled = setting.get('enabled').composite;
            if (enabled) {
                notebooks.widgetAdded.connect((sender, panel) => {
                    var _a, _b;
                    let editor = (_b = (_a = panel.content.activeCell) === null || _a === void 0 ? void 0 : _a.editor) !== null && _b !== void 0 ? _b : null;
                    const session = panel.sessionContext.session;
                    const options = { session, editor };
                    const connector = new CompletionConnector([]);
                    const handler = completionManager.register({
                        connector,
                        editor,
                        parent: panel
                    });
                    const updateConnector = () => {
                        var _a, _b;
                        editor = (_b = (_a = panel.content.activeCell) === null || _a === void 0 ? void 0 : _a.editor) !== null && _b !== void 0 ? _b : null;
                        options.session = panel.sessionContext.session;
                        options.editor = editor;
                        handler.editor = editor;
                        const kernel = new KernelConnector(options);
                        const context = new ContextConnector(options);
                        /*
                         * The custom connector is getting initialized with settings.
                         * This is used to get the updated settings while making the
                         * completer api call.
                         */
                        const custom = new CustomConnector(options, panel, setting);
                        handler.connector = new CompletionConnector([
                            custom,
                            kernel,
                            context
                        ]);
                    };
                    // Update the handler whenever the prompt or session changes
                    panel.content.activeCellChanged.connect(updateConnector);
                    panel.sessionContext.sessionChanged.connect(updateConnector);
                });
                // Add notebook completer command.
                app.commands.addCommand(CommandIDs.invokeNotebook, {
                    execute: () => {
                        var _a;
                        const panel = notebooks.currentWidget;
                        if (panel && ((_a = panel.content.activeCell) === null || _a === void 0 ? void 0 : _a.model.type) === 'code') {
                            return app.commands.execute(CommandIDs.invoke, {
                                id: panel.id
                            });
                        }
                    }
                });
                // Add notebook completer select command.
                app.commands.addCommand(CommandIDs.selectNotebook, {
                    execute: () => {
                        const id = notebooks.currentWidget && notebooks.currentWidget.id;
                        if (id) {
                            return app.commands.execute(CommandIDs.select, { id });
                        }
                    }
                });
                // Set enter key for notebook completer select command.
                app.commands.addKeyBinding({
                    command: CommandIDs.selectNotebook,
                    keys: ['Enter'],
                    selector: '.jp-Notebook .jp-mod-completer-active'
                });
            }
        });
    }
};
export default completer;
