import { DisposableDelegate } from '@lumino/disposable';
import { MutableAiRunner } from './widgets/Toolbar';
export class ToolbarWidget {
    constructor(config) {
        this._trans = config.trans;
        this._handlers = config.handlers;
    }
    /**
     * Create a new extension for the notebook panel widget.
     *
     * @param panel Notebook panel
     * @param context Notebook context
     * @returns Disposable on the added button
     */
    createNew(panel, context) {
        const button = new MutableAiRunner(panel.content, this._handlers, context, this._trans);
        panel.toolbar.insertItem(10, 'Mutable AI', button);
        return new DisposableDelegate(() => {
            button.dispose();
        });
    }
}
export class ToolbarManager {
    constructor(config) {
        this._docRegistry = config.docRegistry;
        this._trans = config.trans;
        this._handlers = config.handlers;
    }
    initialize() {
        const toolbarItem = new ToolbarWidget({
            trans: this._trans,
            handlers: this._handlers
        });
        this._toolbar = this._docRegistry.addWidgetExtension('Notebook', toolbarItem);
    }
    dispose() {
        var _a;
        (_a = this._toolbar) === null || _a === void 0 ? void 0 : _a.dispose();
    }
}
