import { ReactWidget } from '@jupyterlab/apputils';
import { showDialog, Dialog } from '@jupyterlab/apputils';
import React, { useState, useEffect } from 'react';
const SettingsComponent = (props) => {
    const { setting, close } = props;
    const [autoCompleteFlag, setAutoCompleteFlag] = useState(false);
    const [apiKey, setApiKey] = useState('');
    const [autocompleteDomain, setAutocompleteDomain] = useState('');
    const [transformDomain, setTransformDomain] = useState('');
    const setValues = () => {
        // Read the settings and convert to the correct type
        setAutoCompleteFlag(setting.get('flag').composite);
        setApiKey(setting.get('apiKey').composite);
        setAutocompleteDomain(setting.get('autocompleteDomain').composite);
        setTransformDomain(setting.get('transformDomain').composite);
    };
    const restoreToDefault = () => {
        /*
         * This fetches the default settings from
         * user settings then sets then sets it
         * in the form. But as the form is not
         * submitted it is not saved until save
         * button is pressed.
         */
        const flagDefault = setting.default('flag');
        const apiKeyDefault = setting.default('apiKey');
        const autocompleteDomainDefault = setting.default('autocompleteDomain');
        const transformDomainDefault = setting.default('transformDomain');
        setAutoCompleteFlag(flagDefault);
        setApiKey(apiKeyDefault);
        setAutocompleteDomain(autocompleteDomainDefault);
        setTransformDomain(transformDomainDefault);
        setting.set('flag', flagDefault);
        setting.set('apiKey', apiKeyDefault);
        setting.set('autocompleteDomain', autocompleteDomainDefault);
        setting.set('transformDomain', transformDomainDefault);
    };
    /*
     * Whenever the settings object is changed from
     * outside the widget it updates the form accordingly.
     */
    setting.changed.connect(setValues);
    useEffect(() => {
        /*
         * When the widget is attached.
         * It gets the last values from
         * settings object and updates the
         * settings form.
         */
        setValues();
    }, []);
    const handleSubmit = (e) => {
        /*
         * This function gets the submitted form
         * It then updates the values from form-data
         * After that the latest data is saved in user-settings.
         * Also after successful saving it shows a
         */
        e.preventDefault();
        const okButton = Dialog.okButton({
            className: 'btn jp-mutableai-modal-btn'
        });
        try {
            setting.set('flag', autoCompleteFlag);
            setting.set('apiKey', apiKey);
            setting.set('autocompleteDomain', autocompleteDomain);
            setting.set('transformDomain', transformDomain);
            // Success dialog.
            showDialog({
                title: 'Mutable AI Settings',
                body: 'The changes saved successfully!',
                buttons: [okButton]
            });
        }
        catch (e) {
            // Error dialog.
            showDialog({
                title: 'Mutable AI Settings',
                body: 'Something went wrong saving settings. Reason: ' + e.toString(),
                buttons: [okButton]
            });
        }
    };
    return (React.createElement("div", { className: "jp-mutableai-container" },
        React.createElement("h1", null, "Mutable AI Settings"),
        React.createElement("div", { className: "jp-mutableai-header" },
            React.createElement("button", { className: "btn btn-secondary", type: "button", onClick: restoreToDefault }, "Restore to Defaults")),
        React.createElement("form", { className: "jp-mutableai-form", onSubmit: handleSubmit },
            React.createElement("div", { className: "jp-mutableai-group " },
                React.createElement("label", null, "Autocomplete Flag"),
                React.createElement("input", { type: "checkbox", checked: autoCompleteFlag, onChange: e => setAutoCompleteFlag(e.target.checked) }),
                React.createElement("span", null, "This controls whether or not autocomplete is activated.")),
            React.createElement("div", { className: "jp-mutableai-group " },
                React.createElement("label", null, "API key"),
                React.createElement("input", { className: "form-control", placeholder: "", type: "text", value: apiKey, onChange: e => setApiKey(e.target.value) }),
                React.createElement("span", null, "This is the api key to call the endpoints.")),
            React.createElement("div", { className: "jp-mutableai-group " },
                React.createElement("label", null, "Autocomplete Domain"),
                React.createElement("input", { className: "form-control", placeholder: "", type: "text", value: autocompleteDomain, onChange: e => setAutocompleteDomain(e.target.value) }),
                React.createElement("span", null, "Used to construct url to call autocomplete endpoint")),
            React.createElement("div", { className: "jp-mutableai-group " },
                React.createElement("label", null, "Transform Domain"),
                React.createElement("input", { className: "form-control", placeholder: "", type: "text", value: transformDomain, onChange: e => setTransformDomain(e.target.value) }),
                React.createElement("span", null, "Used to construct url to call transform endpoint")),
            React.createElement("div", { className: "jp-mutableai-footer" },
                React.createElement("button", { className: "btn btn-secondary", type: "button", onClick: close }, "Cancel"),
                React.createElement("button", { className: "btn btn-success", type: "submit" }, "Save")))));
};
export class SettingsWidget extends ReactWidget {
    constructor(setting, close) {
        super();
        // This is the top widget class for settings widget.
        this.addClass('jp-mutableai-widget');
        // settings object passed here is used.
        // This is used to get, set, update
        // mutable AI settings.
        this.setting = setting;
        // This is used to close the shell.
        this.closeShell = close;
    }
    render() {
        // This is the settings component passed to the widget.
        return (React.createElement(SettingsComponent, { setting: this.setting, close: () => this.closeShell() }));
    }
}
